add_signed

Function add_signed 

fn add_signed(counter: &AtomicUsize, diff: isize)
Add a signed diff to counter.

Panics

Panics if the result would be negative, which means a retirement was never matched by an announcement.