fn add_signed(counter: &AtomicUsize, diff: isize)Expand description
Add a signed diff to counter.
Panics
Panics if the result would be negative, which means a retirement was never matched by an announcement.
fn add_signed(counter: &AtomicUsize, diff: isize)Add a signed diff to counter.
Panics if the result would be negative, which means a retirement was never matched by an announcement.