fn sub_checked(counter: &AtomicUsize, sub: usize)Expand description
Subtract sub from counter.
Panics
Panics if the result would be negative, which means a retirement was never matched by an announcement.
fn sub_checked(counter: &AtomicUsize, sub: usize)Subtract sub from counter.
Panics if the result would be negative, which means a retirement was never matched by an announcement.